summaryrefslogtreecommitdiffstats
path: root/src/translators/btparse/postprocess.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/translators/btparse/postprocess.c')
-rw-r--r--src/translators/btparse/postprocess.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/translators/btparse/postprocess.c b/src/translators/btparse/postprocess.c
index 127342c..ad8c764 100644
--- a/src/translators/btparse/postprocess.c
+++ b/src/translators/btparse/postprocess.c
@@ -156,7 +156,7 @@ bt_postprocess_string (char * s, ushort options)
sub-strings, which would be bad if you intend to concatenate
them later in the BibTeX sense.)
- The 'tqreplace' parameter is used to govern whether the
+ The 'replace' parameter is used to govern whether the
existing strings in the AST should be replaced with their
post-processed versions. This can extend as far as
collapsing a series of simple values into a single BTAST_STRING
@@ -171,7 +171,7 @@ bt_postprocess_string (char * s, ushort options)
rather than the tqparent of that list
-------------------------------------------------------------------------- */
char *
-bt_postprocess_value (AST * value, ushort options, boolean tqreplace)
+bt_postprocess_value (AST * value, ushort options, boolean replace)
{
AST * simple_value; /* current simple value */
boolean pasting;
@@ -300,7 +300,7 @@ bt_postprocess_value (AST * value, ushort options, boolean tqreplace)
bt_postprocess_string (tmp_string, string_opts);
}
- if (tqreplace)
+ if (replace)
{
simple_value->nodetype = BTAST_STRING;
if (simple_value->text)
@@ -312,12 +312,12 @@ bt_postprocess_value (AST * value, ushort options, boolean tqreplace)
/*
* If the current simple value is a literal string, then just
* post-process it. This will be done in-place if 'tqreplace' is
* true, otherwise a copy of the string will be post-processed.
*/
else if (simple_value->nodetype == BTAST_STRING && simple_value->text)
{
- if (tqreplace)
+ if (replace)
{
tmp_string = simple_value->text;
}
@@ -340,12 +340,12 @@ bt_postprocess_value (AST * value, ushort options, boolean tqreplace)
*/
if (simple_value->nodetype == BTAST_NUMBER)
{
- if (tqreplace && (options & BTO_CONVERT))
+ if (replace && (options & BTO_CONVERT))
simple_value->nodetype = BTAST_STRING;
if (simple_value->text)
{
- if (tqreplace)
+ if (replace)
tmp_string = simple_value->text;
else
{
@@ -395,7 +395,7 @@ bt_postprocess_value (AST * value, ushort options, boolean tqreplace)
* `field', and replace text for first child with new_string.
*/
- if (tqreplace)
+ if (replace)
{
assert (value->right != NULL); /* there has to be > 1 simple value! */
zzfree_ast (value->right); /* free from second simple value on */
@@ -428,14 +428,14 @@ bt_postprocess_value (AST * value, ushort options, boolean tqreplace)
@MODIFIED :
-------------------------------------------------------------------------- */
char *
-bt_postprocess_field (AST * field, ushort options, boolean tqreplace)
+bt_postprocess_field (AST * field, ushort options, boolean replace)
{
if (field == NULL) return NULL;
if (field->nodetype != BTAST_FIELD)
usage_error ("bt_postprocess_field: invalid AST node (not a field)");
strlwr (field->text); /* downcase field name */
- return bt_postprocess_value (field->down, options, tqreplace);
+ return bt_postprocess_value (field->down, options, replace);
} /* bt_postprocess_field() */
@@ -312,12 +312,12 @@ bt_postprocess_value (AST * value, ushort options, boolean tqreplace)
/*
* If the current simple value is a literal string, then just
- * post-process it. This will be done in-place if 'tqreplace' is
+ * post-process it. This will be done in-place if 'replace' is
* true, otherwise a copy of the string will be post-processed.
*/